import {connect} from "react-redux";
import styled from 'styled-components';
import {useEffect} from "react";
import {setActiveUserAllPostsAsync, setUserDataAsync} from "../store/actionCreators/ActionCreators";
import avatar from "../assets/img/avatarGolub.jpg";
import Post from "./Post";
import UserInfoBlock from "./UserInfoBlock";


const UserContentWrapper = styled.div`
  margin-top: 30px;
  width: 100%;
  display: flex;
  align-items: center;
  flex-direction: column;
`
const AvatarBlock = styled.div`
  display: flex;
  flex-direction: column;
  justify-content: space-around;
  align-items: center;
  margin-right: 100px;
`
const PostsContainer = styled.div`
  display: flex;
  flex-direction: row;
  max-width: 1000px;
  flex-wrap: wrap;
  justify-content: center;
`
const UserInfoWrapper = styled.div`
  display: flex;
  width: 1000px;
  justify-content: center;
  margin-bottom: 30px;
  padding-bottom: 20px;
`
const UserInfoBlockWrapper = styled.div`
  display: flex;
  justify-content: flex-start;
`
const AvatarWrapper = styled.div`
  width: 100px;
  height: 100px;
  border-radius: 50%;
  border: 1px solid grey;
  overflow: hidden;
  display: flex;
  align-items: center;
`

const tempUser = "62c1cc5e4535fc62e2a185ad"; // test - should be deleted


function UserContent(props) {

    useEffect(() => {
        if (!props.activeUser) {
            props.setUserDataAsync(props.id)
        }
        if (props.activeUser && !props.activeUserPosts.length) {

            props.setActiveUserAllPostsAsync(tempUser);
            // props.setActiveUserAllPostsAsync(props.activeUser._id)
        }
    })
    console.log(props.activeUserPosts)
    return (
        <>
            {props.activeUser && <UserContentWrapper>
                <UserInfoWrapper>
                    <AvatarBlock>
                        <AvatarWrapper>
                            <img style={{height: "100%"}}
                                 src={props.activeUser && props.activeUser.avatar ? props.activeUser.avatar.url : avatar}
                                 alt={"avatar"}/>
                        </AvatarWrapper>
                        <h2>{props.activeUser.login}</h2>
                    </AvatarBlock>
                    <UserInfoBlockWrapper>
                        <UserInfoBlock count={props.activeUserPosts?.length} description={"posts"}/>
                        <UserInfoBlock count={props.activeUser.followers?.length} description={"followers"}/>
                        <UserInfoBlock count={props.activeUser.following?.length} description={"followings"}/>
                    </UserInfoBlockWrapper>
                </UserInfoWrapper>

                {props.activeUserPosts &&
                <PostsContainer>
                    {props.activeUserPosts.map((post, index) => <Post activeUser={props.activeUser} postId={post._id} key={index}/>)}
                </PostsContainer>}
            </UserContentWrapper>
            }
        </>
    )
}


const mapStateToProps = (state) => {
    return {
        id: state.auth.user.sub.id,
        activeUser: state.activeUser,
        activeUserPosts: state.activeUserPosts,
    }
}

const mapDispatchToProps = (dispatch) => {
    return {
        setUserDataAsync: (id) => dispatch(setUserDataAsync(id)),
        setActiveUserAllPostsAsync: (id) => dispatch(setActiveUserAllPostsAsync(id)),
    }
}

export default connect(mapStateToProps, mapDispatchToProps)(UserContent);